import { Application } from "express";
/**
 * Simple console application that hosts an express HTTP
 * server that simulates an AWS ALB.
 *
 * A request is mapped from the HTTP request to a lambda
 * target, the response from invoking the lambda is mapped to
 * a standard HTTP response and returned to the express client.
 */
export declare class AlbApp {
    private static readonly MAX_REQUEST_BODY_SIZE;
    private static readonly HTTP_METHODS_WITH_ENTITY;
    static readonly APP_OPTIONS: any[];
    protected readonly expressApp: Application;
    private server?;
    private debugEnabled;
    private config;
    private lambdaClient;
    constructor();
    /**
     * Starts the express server.
     *
     * @param args Command line arguments for this server, equivalent to `process.argv.splice(2)`.
     *             See --help for more info.
     */
    runServer(args: string[]): Promise<void>;
    private log;
    private parseArguments;
    private readConfig;
    private configureServer;
    private configureAws;
    private setupAlbTargetListeners;
    private handleHttpRequest;
    private mapRequestToApiEvent;
    private run;
    private forwardApiResponse;
    private startServer;
    stopServer(): Promise<void>;
}
